#version 330 core

out vec4 FragColour;

in vec3 FragPos;
in vec3 Normal;

struct DirectionalLight {
    vec3 direction;

    vec3 ambient;
    vec3 diffuse;
    vec3 specular;
};

uniform vec3 viewPosition;
uniform DirectionalLight dirLight;

vec3 CalculateDirectionalLight(DirectionalLight light, vec3 normal, vec3 viewDir)
{
    vec3 lightDir = normalize(-light.direction);

    float diff = max(dot(normal, lightDir), 0.0);

    vec3 reflectionDir = reflect(-lightDir, normal);
    float spec = pow(max(dot(viewDir, reflectionDir), 0.0), 32);

    vec3 ambient = light.ambient;// * vec3(texture(material.diffuseMap, TexCoords));
    vec3 diffuse = light.diffuse * diff;// * vec3(texture(material.diffuseMap, TexCoords));
    vec3 specular = light.specular * spec;// * vec3(texture(material.specularMap, TexCoords));

    return ambient + diffuse + specular;
}

void main()
{
    vec3 normal = normalize(Normal);
    vec3 viewDir = normalize(viewPosition - FragPos);

//    vec3 col = vec3(1.0, 0.5, 0.2) * FragPos;
    vec3 col = CalculateDirectionalLight(dirLight, normal, viewDir);
    FragColour = vec4(col, 1);
}